@@ -9,7 +9,7 @@ extern "system" {
     pub fn CryptUIDlgCertMgr(pcryptuicertmgr: *const CRYPTUI_CERT_MGR_STRUCT) -> super::super::super::Foundation::BOOL;
     #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
     #[cfg(feature = "Win32_Foundation")]
-    pub fn CryptUIDlgSelectCertificateFromStore(hcertstore: *const ::core::ffi::c_void, hwnd: super::super::super::Foundation::HWND, pwsztitle: super::super::super::Foundation::PWSTR, pwszdisplaystring: super::super::super::Foundation::PWSTR, dwdontusecolumn: u32, dwflags: u32, pvreserved: *const ::core::ffi::c_void) -> *mut super::CERT_CONTEXT;
+    pub fn CryptUIDlgSelectCertificateFromStore(hcertstore: super::HCERTSTORE, hwnd: super::super::super::Foundation::HWND, pwsztitle: ::windows_sys::core::PCWSTR, pwszdisplaystring: ::windows_sys::core::PCWSTR, dwdontusecolumn: u32, dwflags: u32, pvreserved: *const ::core::ffi::c_void) -> *mut super::CERT_CONTEXT;
     #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation', 'Win32_Graphics_Gdi', 'Win32_Security_Cryptography_Catalog', 'Win32_Security_Cryptography_Sip', 'Win32_Security_WinTrust', 'Win32_UI_Controls', 'Win32_UI_WindowsAndMessaging'*"]
     #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Graphics_Gdi", feature = "Win32_Security_Cryptography_Catalog", feature = "Win32_Security_Cryptography_Sip", feature = "Win32_Security_WinTrust", feature = "Win32_UI_Controls", feature = "Win32_UI_WindowsAndMessaging"))]
     pub fn CryptUIDlgViewCertificateA(pcertviewinfo: *const CRYPTUI_VIEWCERTIFICATE_STRUCTA, pfpropertieschanged: *mut super::super::super::Foundation::BOOL) -> super::super::super::Foundation::BOOL;
@@ -18,19 +18,19 @@ extern "system" {
     pub fn CryptUIDlgViewCertificateW(pcertviewinfo: *const CRYPTUI_VIEWCERTIFICATE_STRUCTW, pfpropertieschanged: *mut super::super::super::Foundation::BOOL) -> super::super::super::Foundation::BOOL;
     #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
     #[cfg(feature = "Win32_Foundation")]
-    pub fn CryptUIDlgViewContext(dwcontexttype: u32, pvcontext: *const ::core::ffi::c_void, hwnd: super::super::super::Foundation::HWND, pwsztitle: super::super::super::Foundation::PWSTR, dwflags: u32, pvreserved: *const ::core::ffi::c_void) -> super::super::super::Foundation::BOOL;
+    pub fn CryptUIDlgViewContext(dwcontexttype: u32, pvcontext: *const ::core::ffi::c_void, hwnd: super::super::super::Foundation::HWND, pwsztitle: ::windows_sys::core::PCWSTR, dwflags: u32, pvreserved: *const ::core::ffi::c_void) -> super::super::super::Foundation::BOOL;
     #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
     #[cfg(feature = "Win32_Foundation")]
-    pub fn CryptUIWizDigitalSign(dwflags: u32, hwndparent: super::super::super::Foundation::HWND, pwszwizardtitle: super::super::super::Foundation::PWSTR, pdigitalsigninfo: *const CRYPTUI_WIZ_DIGITAL_SIGN_INFO, ppsigncontext: *mut *mut CRYPTUI_WIZ_DIGITAL_SIGN_CONTEXT) -> super::super::super::Foundation::BOOL;
+    pub fn CryptUIWizDigitalSign(dwflags: u32, hwndparent: super::super::super::Foundation::HWND, pwszwizardtitle: ::windows_sys::core::PCWSTR, pdigitalsigninfo: *const CRYPTUI_WIZ_DIGITAL_SIGN_INFO, ppsigncontext: *mut *mut CRYPTUI_WIZ_DIGITAL_SIGN_CONTEXT) -> super::super::super::Foundation::BOOL;
     #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
     #[cfg(feature = "Win32_Foundation")]
-    pub fn CryptUIWizExport(dwflags: CRYPTUI_WIZ_FLAGS, hwndparent: super::super::super::Foundation::HWND, pwszwizardtitle: super::super::super::Foundation::PWSTR, pexportinfo: *const CRYPTUI_WIZ_EXPORT_INFO, pvoid: *const ::core::ffi::c_void) -> super::super::super::Foundation::BOOL;
+    pub fn CryptUIWizExport(dwflags: CRYPTUI_WIZ_FLAGS, hwndparent: super::super::super::Foundation::HWND, pwszwizardtitle: ::windows_sys::core::PCWSTR, pexportinfo: *const CRYPTUI_WIZ_EXPORT_INFO, pvoid: *const ::core::ffi::c_void) -> super::super::super::Foundation::BOOL;
     #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
     #[cfg(feature = "Win32_Foundation")]
     pub fn CryptUIWizFreeDigitalSignContext(psigncontext: *const CRYPTUI_WIZ_DIGITAL_SIGN_CONTEXT) -> super::super::super::Foundation::BOOL;
     #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
     #[cfg(feature = "Win32_Foundation")]
-    pub fn CryptUIWizImport(dwflags: CRYPTUI_WIZ_FLAGS, hwndparent: super::super::super::Foundation::HWND, pwszwizardtitle: super::super::super::Foundation::PWSTR, pimportsrc: *const CRYPTUI_WIZ_IMPORT_SRC_INFO, hdestcertstore: *const ::core::ffi::c_void) -> super::super::super::Foundation::BOOL;
+    pub fn CryptUIWizImport(dwflags: CRYPTUI_WIZ_FLAGS, hwndparent: super::super::super::Foundation::HWND, pwszwizardtitle: ::windows_sys::core::PCWSTR, pimportsrc: *const CRYPTUI_WIZ_IMPORT_SRC_INFO, hdestcertstore: super::HCERTSTORE) -> super::super::super::Foundation::BOOL;
 }
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
 pub const ACTION_REVOCATION_DEFAULT_CACHE: u32 = 131072u32;
@@ -80,7 +80,7 @@ pub const CERT_FILTER_VALID_TIME_RANGE: u32 = 2u32;
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct CERT_SELECTUI_INPUT {
-    pub hStore: *mut ::core::ffi::c_void,
+    pub hStore: super::HCERTSTORE,
     pub prgpChain: *mut *mut super::CERT_CHAIN_CONTEXT,
     pub cChain: u32,
 }
@@ -99,18 +99,18 @@ pub struct CERT_SELECT_STRUCT_A {
     pub dwSize: u32,
     pub hwndParent: super::super::super::Foundation::HWND,
     pub hInstance: super::super::super::Foundation::HINSTANCE,
-    pub pTemplateName: super::super::super::Foundation::PSTR,
+    pub pTemplateName: ::windows_sys::core::PCSTR,
     pub dwFlags: CERT_SELECT_STRUCT_FLAGS,
-    pub szTitle: super::super::super::Foundation::PSTR,
+    pub szTitle: ::windows_sys::core::PCSTR,
     pub cCertStore: u32,
-    pub arrayCertStore: *mut *mut ::core::ffi::c_void,
-    pub szPurposeOid: super::super::super::Foundation::PSTR,
+    pub arrayCertStore: *mut super::HCERTSTORE,
+    pub szPurposeOid: ::windows_sys::core::PCSTR,
     pub cCertContext: u32,
     pub arrayCertContext: *mut *mut super::CERT_CONTEXT,
     pub lCustData: super::super::super::Foundation::LPARAM,
     pub pfnHook: PFNCMHOOKPROC,
     pub pfnFilter: PFNCMFILTERPROC,
-    pub szHelpFileName: super::super::super::Foundation::PSTR,
+    pub szHelpFileName: ::windows_sys::core::PCSTR,
     pub dwHelpId: u32,
     pub hprov: usize,
 }
@@ -143,18 +143,18 @@ pub struct CERT_SELECT_STRUCT_W {
     pub dwSize: u32,
     pub hwndParent: super::super::super::Foundation::HWND,
     pub hInstance: super::super::super::Foundation::HINSTANCE,
-    pub pTemplateName: super::super::super::Foundation::PWSTR,
+    pub pTemplateName: ::windows_sys::core::PCWSTR,
     pub dwFlags: CERT_SELECT_STRUCT_FLAGS,
-    pub szTitle: super::super::super::Foundation::PWSTR,
+    pub szTitle: ::windows_sys::core::PCWSTR,
     pub cCertStore: u32,
-    pub arrayCertStore: *mut *mut ::core::ffi::c_void,
-    pub szPurposeOid: super::super::super::Foundation::PSTR,
+    pub arrayCertStore: *mut super::HCERTSTORE,
+    pub szPurposeOid: ::windows_sys::core::PCSTR,
     pub cCertContext: u32,
     pub arrayCertContext: *mut *mut super::CERT_CONTEXT,
     pub lCustData: super::super::super::Foundation::LPARAM,
     pub pfnHook: PFNCMHOOKPROC,
     pub pfnFilter: PFNCMFILTERPROC,
-    pub szHelpFileName: super::super::super::Foundation::PWSTR,
+    pub szHelpFileName: ::windows_sys::core::PCWSTR,
     pub dwHelpId: u32,
     pub hprov: usize,
 }
@@ -219,18 +219,18 @@ pub const CERT_VALIDITY_UNKNOWN_CRITICAL_EXTENSION: u32 = 128u32;
 #[cfg(feature = "Win32_Foundation")]
 pub struct CERT_VERIFY_CERTIFICATE_TRUST {
     pub cbSize: u32,
-    pub pccert: *mut super::CERT_CONTEXT,
+    pub pccert: *const super::CERT_CONTEXT,
     pub dwFlags: u32,
     pub dwIgnoreErr: u32,
     pub pdwErrors: *mut u32,
-    pub pszUsageOid: super::super::super::Foundation::PSTR,
+    pub pszUsageOid: ::windows_sys::core::PSTR,
     pub hprov: usize,
     pub cRootStores: u32,
-    pub rghstoreRoots: *mut *mut ::core::ffi::c_void,
+    pub rghstoreRoots: *mut super::HCERTSTORE,
     pub cStores: u32,
-    pub rghstoreCAs: *mut *mut ::core::ffi::c_void,
+    pub rghstoreCAs: *mut super::HCERTSTORE,
     pub cTrustStores: u32,
-    pub rghstoreTrust: *mut *mut ::core::ffi::c_void,
+    pub rghstoreTrust: *mut super::HCERTSTORE,
     pub lCustData: super::super::super::Foundation::LPARAM,
     pub pfnTrustHelper: PFNTRUSTHELPER,
     pub pcChain: *mut u32,
@@ -254,20 +254,20 @@ pub struct CERT_VIEWPROPERTIES_STRUCT_A {
     pub hwndParent: super::super::super::Foundation::HWND,
     pub hInstance: super::super::super::Foundation::HINSTANCE,
     pub dwFlags: CERT_VIEWPROPERTIES_STRUCT_FLAGS,
-    pub szTitle: super::super::super::Foundation::PSTR,
-    pub pCertContext: *mut super::CERT_CONTEXT,
-    pub arrayPurposes: *mut super::super::super::Foundation::PSTR,
+    pub szTitle: ::windows_sys::core::PCSTR,
+    pub pCertContext: *const super::CERT_CONTEXT,
+    pub arrayPurposes: *mut ::windows_sys::core::PSTR,
     pub cArrayPurposes: u32,
     pub cRootStores: u32,
-    pub rghstoreRoots: *mut *mut ::core::ffi::c_void,
+    pub rghstoreRoots: *mut super::HCERTSTORE,
     pub cStores: u32,
-    pub rghstoreCAs: *mut *mut ::core::ffi::c_void,
+    pub rghstoreCAs: *mut super::HCERTSTORE,
     pub cTrustStores: u32,
-    pub rghstoreTrust: *mut *mut ::core::ffi::c_void,
+    pub rghstoreTrust: *mut super::HCERTSTORE,
     pub hprov: usize,
     pub lCustData: super::super::super::Foundation::LPARAM,
     pub dwPad: u32,
-    pub szHelpFileName: super::super::super::Foundation::PSTR,
+    pub szHelpFileName: ::windows_sys::core::PCSTR,
     pub dwHelpId: u32,
     pub nStartPage: u32,
     pub cArrayPropSheetPages: u32,
@@ -311,20 +311,20 @@ pub struct CERT_VIEWPROPERTIES_STRUCT_W {
     pub hwndParent: super::super::super::Foundation::HWND,
     pub hInstance: super::super::super::Foundation::HINSTANCE,
     pub dwFlags: CERT_VIEWPROPERTIES_STRUCT_FLAGS,
-    pub szTitle: super::super::super::Foundation::PWSTR,
-    pub pCertContext: *mut super::CERT_CONTEXT,
-    pub arrayPurposes: *mut super::super::super::Foundation::PSTR,
+    pub szTitle: ::windows_sys::core::PCWSTR,
+    pub pCertContext: *const super::CERT_CONTEXT,
+    pub arrayPurposes: *mut ::windows_sys::core::PSTR,
     pub cArrayPurposes: u32,
     pub cRootStores: u32,
-    pub rghstoreRoots: *mut *mut ::core::ffi::c_void,
+    pub rghstoreRoots: *mut super::HCERTSTORE,
     pub cStores: u32,
-    pub rghstoreCAs: *mut *mut ::core::ffi::c_void,
+    pub rghstoreCAs: *mut super::HCERTSTORE,
     pub cTrustStores: u32,
-    pub rghstoreTrust: *mut *mut ::core::ffi::c_void,
+    pub rghstoreTrust: *mut super::HCERTSTORE,
     pub hprov: usize,
     pub lCustData: super::super::super::Foundation::LPARAM,
     pub dwPad: u32,
-    pub szHelpFileName: super::super::super::Foundation::PWSTR,
+    pub szHelpFileName: ::windows_sys::core::PCWSTR,
     pub dwHelpId: u32,
     pub nStartPage: u32,
     pub cArrayPropSheetPages: u32,
@@ -339,34 +339,28 @@ impl ::core::clone::Clone for CERT_VIEWPROPERTIES_STRUCT_W {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
+#[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
 pub struct CMFLTR {
     pub dwSize: u32,
     pub cExtensionChecks: u32,
     pub arrayExtensionChecks: *mut CMOID,
     pub dwCheckingFlags: u32,
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CMFLTR {}
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::clone::Clone for CMFLTR {
     fn clone(&self) -> Self {
         *self
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
+#[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
 pub struct CMOID {
-    pub szExtensionOID: super::super::super::Foundation::PSTR,
+    pub szExtensionOID: ::windows_sys::core::PCSTR,
     pub dwTestOperation: u32,
     pub pbTestData: *mut u8,
     pub cbTestData: u32,
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CMOID {}
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::clone::Clone for CMOID {
     fn clone(&self) -> Self {
         *self
@@ -401,8 +395,8 @@ pub struct CRYPTUI_CERT_MGR_STRUCT {
     pub dwSize: u32,
     pub hwndParent: super::super::super::Foundation::HWND,
     pub dwFlags: u32,
-    pub pwszTitle: super::super::super::Foundation::PWSTR,
-    pub pszInitUsageOID: super::super::super::Foundation::PSTR,
+    pub pwszTitle: ::windows_sys::core::PCWSTR,
+    pub pszInitUsageOID: ::windows_sys::core::PCSTR,
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CRYPTUI_CERT_MGR_STRUCT {}
@@ -419,7 +413,7 @@ pub const CRYPTUI_CERT_MGR_TAB_MASK: u32 = 15u32;
 #[cfg(feature = "Win32_Foundation")]
 pub struct CRYPTUI_INITDIALOG_STRUCT {
     pub lParam: super::super::super::Foundation::LPARAM,
-    pub pCertContext: *mut super::CERT_CONTEXT,
+    pub pCertContext: *const super::CERT_CONTEXT,
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CRYPTUI_INITDIALOG_STRUCT {}
@@ -490,9 +484,9 @@ pub struct CRYPTUI_VIEWCERTIFICATE_STRUCTA {
     pub dwSize: u32,
     pub hwndParent: super::super::super::Foundation::HWND,
     pub dwFlags: CRYPTUI_VIEWCERTIFICATE_FLAGS,
-    pub szTitle: super::super::super::Foundation::PSTR,
-    pub pCertContext: *mut super::CERT_CONTEXT,
-    pub rgszPurposes: *mut super::super::super::Foundation::PSTR,
+    pub szTitle: ::windows_sys::core::PCSTR,
+    pub pCertContext: *const super::CERT_CONTEXT,
+    pub rgszPurposes: *mut ::windows_sys::core::PSTR,
     pub cPurposes: u32,
     pub Anonymous: CRYPTUI_VIEWCERTIFICATE_STRUCTA_0,
     pub fpCryptProviderDataTrustedUsage: super::super::super::Foundation::BOOL,
@@ -501,7 +495,7 @@ pub struct CRYPTUI_VIEWCERTIFICATE_STRUCTA {
     pub fCounterSigner: super::super::super::Foundation::BOOL,
     pub idxCounterSigner: u32,
     pub cStores: u32,
-    pub rghStores: *mut *mut ::core::ffi::c_void,
+    pub rghStores: *mut super::HCERTSTORE,
     pub cPropSheetPages: u32,
     pub rgPropSheetPages: *mut super::super::super::UI::Controls::PROPSHEETPAGEA,
     pub nStartPage: u32,
@@ -518,7 +512,7 @@ impl ::core::clone::Clone for CRYPTUI_VIEWCERTIFICATE_STRUCTA {
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation', 'Win32_Graphics_Gdi', 'Win32_Security_Cryptography_Catalog', 'Win32_Security_Cryptography_Sip', 'Win32_Security_WinTrust', 'Win32_UI_Controls', 'Win32_UI_WindowsAndMessaging'*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Graphics_Gdi", feature = "Win32_Security_Cryptography_Catalog", feature = "Win32_Security_Cryptography_Sip", feature = "Win32_Security_WinTrust", feature = "Win32_UI_Controls", feature = "Win32_UI_WindowsAndMessaging"))]
 pub union CRYPTUI_VIEWCERTIFICATE_STRUCTA_0 {
-    pub pCryptProviderData: *mut super::super::WinTrust::CRYPT_PROVIDER_DATA,
+    pub pCryptProviderData: *const super::super::WinTrust::CRYPT_PROVIDER_DATA,
     pub hWVTStateData: super::super::super::Foundation::HANDLE,
 }
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Graphics_Gdi", feature = "Win32_Security_Cryptography_Catalog", feature = "Win32_Security_Cryptography_Sip", feature = "Win32_Security_WinTrust", feature = "Win32_UI_Controls", feature = "Win32_UI_WindowsAndMessaging"))]
@@ -536,9 +530,9 @@ pub struct CRYPTUI_VIEWCERTIFICATE_STRUCTW {
     pub dwSize: u32,
     pub hwndParent: super::super::super::Foundation::HWND,
     pub dwFlags: CRYPTUI_VIEWCERTIFICATE_FLAGS,
-    pub szTitle: super::super::super::Foundation::PWSTR,
-    pub pCertContext: *mut super::CERT_CONTEXT,
-    pub rgszPurposes: *mut super::super::super::Foundation::PSTR,
+    pub szTitle: ::windows_sys::core::PCWSTR,
+    pub pCertContext: *const super::CERT_CONTEXT,
+    pub rgszPurposes: *mut ::windows_sys::core::PSTR,
     pub cPurposes: u32,
     pub Anonymous: CRYPTUI_VIEWCERTIFICATE_STRUCTW_0,
     pub fpCryptProviderDataTrustedUsage: super::super::super::Foundation::BOOL,
@@ -547,7 +541,7 @@ pub struct CRYPTUI_VIEWCERTIFICATE_STRUCTW {
     pub fCounterSigner: super::super::super::Foundation::BOOL,
     pub idxCounterSigner: u32,
     pub cStores: u32,
-    pub rghStores: *mut *mut ::core::ffi::c_void,
+    pub rghStores: *mut super::HCERTSTORE,
     pub cPropSheetPages: u32,
     pub rgPropSheetPages: *mut super::super::super::UI::Controls::PROPSHEETPAGEW,
     pub nStartPage: u32,
@@ -564,7 +558,7 @@ impl ::core::clone::Clone for CRYPTUI_VIEWCERTIFICATE_STRUCTW {
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation', 'Win32_Graphics_Gdi', 'Win32_Security_Cryptography_Catalog', 'Win32_Security_Cryptography_Sip', 'Win32_Security_WinTrust', 'Win32_UI_Controls', 'Win32_UI_WindowsAndMessaging'*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Graphics_Gdi", feature = "Win32_Security_Cryptography_Catalog", feature = "Win32_Security_Cryptography_Sip", feature = "Win32_Security_WinTrust", feature = "Win32_UI_Controls", feature = "Win32_UI_WindowsAndMessaging"))]
 pub union CRYPTUI_VIEWCERTIFICATE_STRUCTW_0 {
-    pub pCryptProviderData: *mut super::super::WinTrust::CRYPT_PROVIDER_DATA,
+    pub pCryptProviderData: *const super::super::WinTrust::CRYPT_PROVIDER_DATA,
     pub hWVTStateData: super::super::super::Foundation::HANDLE,
 }
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Graphics_Gdi", feature = "Win32_Security_Cryptography_Catalog", feature = "Win32_Security_Cryptography_Sip", feature = "Win32_Security_WinTrust", feature = "Win32_UI_Controls", feature = "Win32_UI_WindowsAndMessaging"))]
@@ -594,50 +588,41 @@ pub const CRYPTUI_WIZ_DIGITAL_SIGN_PVK: CRYPTUI_WIZ_DIGITAL_SIGN = 3u32;
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
 pub const CRYPTUI_WIZ_DIGITAL_SIGN_NONE: CRYPTUI_WIZ_DIGITAL_SIGN = 0u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
+#[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
 pub struct CRYPTUI_WIZ_DIGITAL_SIGN_BLOB_INFO {
     pub dwSize: u32,
     pub pGuidSubject: *mut ::windows_sys::core::GUID,
     pub cbBlob: u32,
     pub pbBlob: *mut u8,
-    pub pwszDisplayName: super::super::super::Foundation::PWSTR,
+    pub pwszDisplayName: ::windows_sys::core::PCWSTR,
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CRYPTUI_WIZ_DIGITAL_SIGN_BLOB_INFO {}
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::clone::Clone for CRYPTUI_WIZ_DIGITAL_SIGN_BLOB_INFO {
     fn clone(&self) -> Self {
         *self
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
+#[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
 pub struct CRYPTUI_WIZ_DIGITAL_SIGN_CERT_PVK_INFO {
     pub dwSize: u32,
-    pub pwszSigningCertFileName: super::super::super::Foundation::PWSTR,
+    pub pwszSigningCertFileName: ::windows_sys::core::PWSTR,
     pub dwPvkChoice: CRYPTUI_WIZ_DIGITAL_SIGN_PVK_OPTION,
     pub Anonymous: CRYPTUI_WIZ_DIGITAL_SIGN_CERT_PVK_INFO_0,
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CRYPTUI_WIZ_DIGITAL_SIGN_CERT_PVK_INFO {}
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::clone::Clone for CRYPTUI_WIZ_DIGITAL_SIGN_CERT_PVK_INFO {
     fn clone(&self) -> Self {
         *self
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
+#[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
 pub union CRYPTUI_WIZ_DIGITAL_SIGN_CERT_PVK_INFO_0 {
     pub pPvkFileInfo: *mut CRYPTUI_WIZ_DIGITAL_SIGN_PVK_FILE_INFO,
     pub pPvkProvInfo: *mut super::CRYPT_KEY_PROV_INFO,
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CRYPTUI_WIZ_DIGITAL_SIGN_CERT_PVK_INFO_0 {}
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::clone::Clone for CRYPTUI_WIZ_DIGITAL_SIGN_CERT_PVK_INFO_0 {
     fn clone(&self) -> Self {
         *self
@@ -659,22 +644,19 @@ impl ::core::clone::Clone for CRYPTUI_WIZ_DIGITAL_SIGN_CONTEXT {
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
 pub const CRYPTUI_WIZ_DIGITAL_SIGN_EXCLUDE_PAGE_HASHES: u32 = 2u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
+#[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
 pub struct CRYPTUI_WIZ_DIGITAL_SIGN_EXTENDED_INFO {
     pub dwSize: u32,
     pub dwAttrFlags: CRYPTUI_WIZ_DIGITAL_SIGN_SIG_TYPE,
-    pub pwszDescription: super::super::super::Foundation::PWSTR,
-    pub pwszMoreInfoLocation: super::super::super::Foundation::PWSTR,
-    pub pszHashAlg: super::super::super::Foundation::PSTR,
-    pub pwszSigningCertDisplayString: super::super::super::Foundation::PWSTR,
-    pub hAdditionalCertStore: *mut ::core::ffi::c_void,
+    pub pwszDescription: ::windows_sys::core::PCWSTR,
+    pub pwszMoreInfoLocation: ::windows_sys::core::PCWSTR,
+    pub pszHashAlg: ::windows_sys::core::PCSTR,
+    pub pwszSigningCertDisplayString: ::windows_sys::core::PCWSTR,
+    pub hAdditionalCertStore: super::HCERTSTORE,
     pub psAuthenticated: *mut super::CRYPT_ATTRIBUTES,
     pub psUnauthenticated: *mut super::CRYPT_ATTRIBUTES,
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CRYPTUI_WIZ_DIGITAL_SIGN_EXTENDED_INFO {}
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::clone::Clone for CRYPTUI_WIZ_DIGITAL_SIGN_EXTENDED_INFO {
     fn clone(&self) -> Self {
         *self
@@ -691,7 +673,7 @@ pub struct CRYPTUI_WIZ_DIGITAL_SIGN_INFO {
     pub Anonymous1: CRYPTUI_WIZ_DIGITAL_SIGN_INFO_0,
     pub dwSigningCertChoice: CRYPTUI_WIZ_DIGITAL_SIGN,
     pub Anonymous2: CRYPTUI_WIZ_DIGITAL_SIGN_INFO_1,
-    pub pwszTimestampURL: super::super::super::Foundation::PWSTR,
+    pub pwszTimestampURL: ::windows_sys::core::PCWSTR,
     pub dwAdditionalCertChoice: CRYPTUI_WIZ_DIGITAL_ADDITIONAL_CERT_CHOICE,
     pub pSignExtInfo: *mut CRYPTUI_WIZ_DIGITAL_SIGN_EXTENDED_INFO,
 }
@@ -707,7 +689,7 @@ impl ::core::clone::Clone for CRYPTUI_WIZ_DIGITAL_SIGN_INFO {
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union CRYPTUI_WIZ_DIGITAL_SIGN_INFO_0 {
-    pub pwszFileName: super::super::super::Foundation::PWSTR,
+    pub pwszFileName: ::windows_sys::core::PCWSTR,
     pub pSignBlobInfo: *mut CRYPTUI_WIZ_DIGITAL_SIGN_BLOB_INFO,
 }
 #[cfg(feature = "Win32_Foundation")]
@@ -722,7 +704,7 @@ impl ::core::clone::Clone for CRYPTUI_WIZ_DIGITAL_SIGN_INFO_0 {
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union CRYPTUI_WIZ_DIGITAL_SIGN_INFO_1 {
-    pub pSigningCertContext: *mut super::CERT_CONTEXT,
+    pub pSigningCertContext: *const super::CERT_CONTEXT,
     pub pSigningCertStore: *mut CRYPTUI_WIZ_DIGITAL_SIGN_STORE_INFO,
     pub pSigningCertPvkInfo: *mut CRYPTUI_WIZ_DIGITAL_SIGN_CERT_PVK_INFO,
 }
@@ -735,17 +717,14 @@ impl ::core::clone::Clone for CRYPTUI_WIZ_DIGITAL_SIGN_INFO_1 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
+#[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
 pub struct CRYPTUI_WIZ_DIGITAL_SIGN_PVK_FILE_INFO {
     pub dwSize: u32,
-    pub pwszPvkFileName: super::super::super::Foundation::PWSTR,
-    pub pwszProvName: super::super::super::Foundation::PWSTR,
+    pub pwszPvkFileName: ::windows_sys::core::PWSTR,
+    pub pwszProvName: ::windows_sys::core::PWSTR,
     pub dwProvType: u32,
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CRYPTUI_WIZ_DIGITAL_SIGN_PVK_FILE_INFO {}
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::clone::Clone for CRYPTUI_WIZ_DIGITAL_SIGN_PVK_FILE_INFO {
     fn clone(&self) -> Self {
         *self
@@ -769,7 +748,7 @@ pub const CRYPTUI_WIZ_DIGITAL_SIGN_INDIVIDUAL: CRYPTUI_WIZ_DIGITAL_SIGN_SIG_TYPE
 pub struct CRYPTUI_WIZ_DIGITAL_SIGN_STORE_INFO {
     pub dwSize: u32,
     pub cCertStore: u32,
-    pub rghCertStore: *mut *mut ::core::ffi::c_void,
+    pub rghCertStore: *mut super::HCERTSTORE,
     pub pFilterCallback: PFNCFILTERPROC,
     pub pvCallbackData: *mut ::core::ffi::c_void,
 }
@@ -797,7 +776,7 @@ pub struct CRYPTUI_WIZ_EXPORT_CERTCONTEXT_INFO {
     pub dwExportFormat: CRYPTUI_WIZ_EXPORT_FORMAT,
     pub fExportChain: super::super::super::Foundation::BOOL,
     pub fExportPrivateKeys: super::super::super::Foundation::BOOL,
-    pub pwszPassword: super::super::super::Foundation::PWSTR,
+    pub pwszPassword: ::windows_sys::core::PCWSTR,
     pub fStrongEncryption: super::super::super::Foundation::BOOL,
 }
 #[cfg(feature = "Win32_Foundation")]
@@ -829,11 +808,11 @@ pub const CRYPTUI_WIZ_EXPORT_FORMAT_SERIALIZED_CERT_STORE: u32 = 5u32;
 #[cfg(feature = "Win32_Foundation")]
 pub struct CRYPTUI_WIZ_EXPORT_INFO {
     pub dwSize: u32,
-    pub pwszExportFileName: super::super::super::Foundation::PWSTR,
+    pub pwszExportFileName: ::windows_sys::core::PCWSTR,
     pub dwSubjectChoice: CRYPTUI_WIZ_EXPORT_SUBJECT,
     pub Anonymous: CRYPTUI_WIZ_EXPORT_INFO_0,
     pub cStores: u32,
-    pub rghStores: *mut *mut ::core::ffi::c_void,
+    pub rghStores: *mut super::HCERTSTORE,
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CRYPTUI_WIZ_EXPORT_INFO {}
@@ -847,10 +826,10 @@ impl ::core::clone::Clone for CRYPTUI_WIZ_EXPORT_INFO {
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union CRYPTUI_WIZ_EXPORT_INFO_0 {
-    pub pCertContext: *mut super::CERT_CONTEXT,
+    pub pCertContext: *const super::CERT_CONTEXT,
     pub pCTLContext: *mut super::CTL_CONTEXT,
     pub pCRLContext: *mut super::CRL_CONTEXT,
-    pub hCertStore: *mut ::core::ffi::c_void,
+    pub hCertStore: super::HCERTSTORE,
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CRYPTUI_WIZ_EXPORT_INFO_0 {}
@@ -906,7 +885,7 @@ pub struct CRYPTUI_WIZ_IMPORT_SRC_INFO {
     pub dwSubjectChoice: CRYPTUI_WIZ_IMPORT_SUBJECT_OPTION,
     pub Anonymous: CRYPTUI_WIZ_IMPORT_SRC_INFO_0,
     pub dwFlags: super::CRYPT_KEY_FLAGS,
-    pub pwszPassword: super::super::super::Foundation::PWSTR,
+    pub pwszPassword: ::windows_sys::core::PCWSTR,
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CRYPTUI_WIZ_IMPORT_SRC_INFO {}
@@ -920,11 +899,11 @@ impl ::core::clone::Clone for CRYPTUI_WIZ_IMPORT_SRC_INFO {
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union CRYPTUI_WIZ_IMPORT_SRC_INFO_0 {
-    pub pwszFileName: super::super::super::Foundation::PWSTR,
-    pub pCertContext: *mut super::CERT_CONTEXT,
+    pub pwszFileName: ::windows_sys::core::PCWSTR,
+    pub pCertContext: *const super::CERT_CONTEXT,
     pub pCTLContext: *mut super::CTL_CONTEXT,
     pub pCRLContext: *mut super::CRL_CONTEXT,
-    pub hCertStore: *mut ::core::ffi::c_void,
+    pub hCertStore: super::HCERTSTORE,
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for CRYPTUI_WIZ_IMPORT_SRC_INFO_0 {}
@@ -954,7 +933,7 @@ pub const CSS_SELECTCERT_MASK: u32 = 16777215u32;
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct CTL_MODIFY_REQUEST {
-    pub pccert: *mut super::CERT_CONTEXT,
+    pub pccert: *const super::CERT_CONTEXT,
     pub dwOperation: CTL_MODIFY_REQUEST_OPERATION,
     pub dwError: u32,
 }
@@ -1004,3 +983,5 @@ pub const SELCERT_SERIAL_NUM: u32 = 106u32;
 pub const SELCERT_THUMBPRINT: u32 = 107u32;
 #[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
 pub const SELCERT_VALIDITY: u32 = 104u32;
+#[doc = "*Required features: 'Win32_Security_Cryptography_UI'*"]
+pub const szCERT_CERTIFICATE_ACTION_VERIFY: &'static str = "{7801ebd0-cf4b-11d0-851f-0060979387ea}";
