@@ -1,37 +1,34 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
 #[link(name = "windows")]
 extern "system" {
+    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
     #[cfg(feature = "Win32_Foundation")]
     pub fn PssCaptureSnapshot(processhandle: super::super::super::Foundation::HANDLE, captureflags: PSS_CAPTURE_FLAGS, threadcontextflags: u32, snapshothandle: *mut HPSS) -> u32;
+    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
     #[cfg(feature = "Win32_Foundation")]
     pub fn PssDuplicateSnapshot(sourceprocesshandle: super::super::super::Foundation::HANDLE, snapshothandle: HPSS, targetprocesshandle: super::super::super::Foundation::HANDLE, targetsnapshothandle: *mut HPSS, flags: PSS_DUPLICATE_FLAGS) -> u32;
+    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
     #[cfg(feature = "Win32_Foundation")]
     pub fn PssFreeSnapshot(processhandle: super::super::super::Foundation::HANDLE, snapshothandle: HPSS) -> u32;
+    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
     pub fn PssQuerySnapshot(snapshothandle: HPSS, informationclass: PSS_QUERY_INFORMATION_CLASS, buffer: *mut ::core::ffi::c_void, bufferlength: u32) -> u32;
+    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
     pub fn PssWalkMarkerCreate(allocator: *const PSS_ALLOCATOR, walkmarkerhandle: *mut HPSSWALK) -> u32;
+    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
     pub fn PssWalkMarkerFree(walkmarkerhandle: HPSSWALK) -> u32;
+    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
     pub fn PssWalkMarkerGetPosition(walkmarkerhandle: HPSSWALK, position: *mut usize) -> u32;
+    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
     pub fn PssWalkMarkerSeekToBeginning(walkmarkerhandle: HPSSWALK) -> u32;
+    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
     pub fn PssWalkMarkerSetPosition(walkmarkerhandle: HPSSWALK, position: usize) -> u32;
+    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
     pub fn PssWalkSnapshot(snapshothandle: HPSS, informationclass: PSS_WALK_INFORMATION_CLASS, walkmarkerhandle: HPSSWALK, buffer: *mut ::core::ffi::c_void, bufferlength: u32) -> u32;
 }
-#[repr(transparent)]
-pub struct HPSS(pub isize);
-impl ::core::marker::Copy for HPSS {}
-impl ::core::clone::Clone for HPSS {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct HPSSWALK(pub isize);
-impl ::core::marker::Copy for HPSSWALK {}
-impl ::core::clone::Clone for HPSSWALK {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+pub type HPSS = isize;
+pub type HPSSWALK = isize;
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_ALLOCATOR {
     pub Context: *mut ::core::ffi::c_void,
     pub AllocRoutine: isize,
@@ -44,6 +41,7 @@ impl ::core::clone::Clone for PSS_ALLOCATOR {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_AUXILIARY_PAGES_INFORMATION {
     pub AuxPagesCaptured: u32,
 }
@@ -54,6 +52,7 @@ impl ::core::clone::Clone for PSS_AUXILIARY_PAGES_INFORMATION {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation', 'Win32_System_Memory'*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Memory"))]
 pub struct PSS_AUXILIARY_PAGE_ENTRY {
     pub Address: *mut ::core::ffi::c_void,
@@ -70,47 +69,60 @@ impl ::core::clone::Clone for PSS_AUXILIARY_PAGE_ENTRY {
         *self
     }
 }
-#[repr(transparent)]
-pub struct PSS_CAPTURE_FLAGS(pub u32);
-pub const PSS_CAPTURE_NONE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(0u32);
-pub const PSS_CAPTURE_VA_CLONE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(1u32);
-pub const PSS_CAPTURE_RESERVED_00000002: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(2u32);
-pub const PSS_CAPTURE_HANDLES: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(4u32);
-pub const PSS_CAPTURE_HANDLE_NAME_INFORMATION: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(8u32);
-pub const PSS_CAPTURE_HANDLE_BASIC_INFORMATION: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(16u32);
-pub const PSS_CAPTURE_HANDLE_TYPE_SPECIFIC_INFORMATION: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(32u32);
-pub const PSS_CAPTURE_HANDLE_TRACE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(64u32);
-pub const PSS_CAPTURE_THREADS: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(128u32);
-pub const PSS_CAPTURE_THREAD_CONTEXT: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(256u32);
-pub const PSS_CAPTURE_THREAD_CONTEXT_EXTENDED: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(512u32);
-pub const PSS_CAPTURE_RESERVED_00000400: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(1024u32);
-pub const PSS_CAPTURE_VA_SPACE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(2048u32);
-pub const PSS_CAPTURE_VA_SPACE_SECTION_INFORMATION: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(4096u32);
-pub const PSS_CAPTURE_IPT_TRACE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(8192u32);
-pub const PSS_CAPTURE_RESERVED_00004000: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(16384u32);
-pub const PSS_CREATE_BREAKAWAY_OPTIONAL: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(67108864u32);
-pub const PSS_CREATE_BREAKAWAY: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(134217728u32);
-pub const PSS_CREATE_FORCE_BREAKAWAY: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(268435456u32);
-pub const PSS_CREATE_USE_VM_ALLOCATIONS: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(536870912u32);
-pub const PSS_CREATE_MEASURE_PERFORMANCE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(1073741824u32);
-pub const PSS_CREATE_RELEASE_SECTION: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(2147483648u32);
-impl ::core::marker::Copy for PSS_CAPTURE_FLAGS {}
-impl ::core::clone::Clone for PSS_CAPTURE_FLAGS {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct PSS_DUPLICATE_FLAGS(pub u32);
-pub const PSS_DUPLICATE_NONE: PSS_DUPLICATE_FLAGS = PSS_DUPLICATE_FLAGS(0u32);
-pub const PSS_DUPLICATE_CLOSE_SOURCE: PSS_DUPLICATE_FLAGS = PSS_DUPLICATE_FLAGS(1u32);
-impl ::core::marker::Copy for PSS_DUPLICATE_FLAGS {}
-impl ::core::clone::Clone for PSS_DUPLICATE_FLAGS {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub type PSS_CAPTURE_FLAGS = u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_NONE: PSS_CAPTURE_FLAGS = 0u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_VA_CLONE: PSS_CAPTURE_FLAGS = 1u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_RESERVED_00000002: PSS_CAPTURE_FLAGS = 2u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_HANDLES: PSS_CAPTURE_FLAGS = 4u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_HANDLE_NAME_INFORMATION: PSS_CAPTURE_FLAGS = 8u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_HANDLE_BASIC_INFORMATION: PSS_CAPTURE_FLAGS = 16u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_HANDLE_TYPE_SPECIFIC_INFORMATION: PSS_CAPTURE_FLAGS = 32u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_HANDLE_TRACE: PSS_CAPTURE_FLAGS = 64u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_THREADS: PSS_CAPTURE_FLAGS = 128u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_THREAD_CONTEXT: PSS_CAPTURE_FLAGS = 256u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_THREAD_CONTEXT_EXTENDED: PSS_CAPTURE_FLAGS = 512u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_RESERVED_00000400: PSS_CAPTURE_FLAGS = 1024u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_VA_SPACE: PSS_CAPTURE_FLAGS = 2048u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_VA_SPACE_SECTION_INFORMATION: PSS_CAPTURE_FLAGS = 4096u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_IPT_TRACE: PSS_CAPTURE_FLAGS = 8192u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CAPTURE_RESERVED_00004000: PSS_CAPTURE_FLAGS = 16384u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CREATE_BREAKAWAY_OPTIONAL: PSS_CAPTURE_FLAGS = 67108864u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CREATE_BREAKAWAY: PSS_CAPTURE_FLAGS = 134217728u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CREATE_FORCE_BREAKAWAY: PSS_CAPTURE_FLAGS = 268435456u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CREATE_USE_VM_ALLOCATIONS: PSS_CAPTURE_FLAGS = 536870912u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CREATE_MEASURE_PERFORMANCE: PSS_CAPTURE_FLAGS = 1073741824u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_CREATE_RELEASE_SECTION: PSS_CAPTURE_FLAGS = 2147483648u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub type PSS_DUPLICATE_FLAGS = u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_DUPLICATE_NONE: PSS_DUPLICATE_FLAGS = 0u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_DUPLICATE_CLOSE_SOURCE: PSS_DUPLICATE_FLAGS = 1u32;
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY {
     pub Handle: super::super::super::Foundation::HANDLE,
@@ -125,9 +137,9 @@ pub struct PSS_HANDLE_ENTRY {
     pub NonPagedPoolCharge: u32,
     pub CreationTime: super::super::super::Foundation::FILETIME,
     pub TypeNameLength: u16,
-    pub TypeName: super::super::super::Foundation::PWSTR,
+    pub TypeName: ::windows_sys::core::PCWSTR,
     pub ObjectNameLength: u16,
-    pub ObjectName: super::super::super::Foundation::PWSTR,
+    pub ObjectName: ::windows_sys::core::PCWSTR,
     pub TypeSpecificInformation: PSS_HANDLE_ENTRY_0,
 }
 #[cfg(feature = "Win32_Foundation")]
@@ -139,6 +151,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union PSS_HANDLE_ENTRY_0 {
     pub Process: PSS_HANDLE_ENTRY_0_2,
@@ -157,6 +170,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0 {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_0 {
     pub ManualReset: super::super::super::Foundation::BOOL,
@@ -171,6 +185,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_0 {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_1 {
     pub CurrentCount: i32,
@@ -187,6 +202,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_1 {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_2 {
     pub ExitStatus: u32,
@@ -206,6 +222,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_2 {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_3 {
     pub BaseAddress: *mut ::core::ffi::c_void,
@@ -221,6 +238,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_3 {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_4 {
     pub CurrentCount: i32,
@@ -235,6 +253,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_4 {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_5 {
     pub ExitStatus: u32,
@@ -254,20 +273,20 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_5 {
         *self
     }
 }
-#[repr(transparent)]
-pub struct PSS_HANDLE_FLAGS(pub u32);
-pub const PSS_HANDLE_NONE: PSS_HANDLE_FLAGS = PSS_HANDLE_FLAGS(0u32);
-pub const PSS_HANDLE_HAVE_TYPE: PSS_HANDLE_FLAGS = PSS_HANDLE_FLAGS(1u32);
-pub const PSS_HANDLE_HAVE_NAME: PSS_HANDLE_FLAGS = PSS_HANDLE_FLAGS(2u32);
-pub const PSS_HANDLE_HAVE_BASIC_INFORMATION: PSS_HANDLE_FLAGS = PSS_HANDLE_FLAGS(4u32);
-pub const PSS_HANDLE_HAVE_TYPE_SPECIFIC_INFORMATION: PSS_HANDLE_FLAGS = PSS_HANDLE_FLAGS(8u32);
-impl ::core::marker::Copy for PSS_HANDLE_FLAGS {}
-impl ::core::clone::Clone for PSS_HANDLE_FLAGS {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub type PSS_HANDLE_FLAGS = u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_HANDLE_NONE: PSS_HANDLE_FLAGS = 0u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_HANDLE_HAVE_TYPE: PSS_HANDLE_FLAGS = 1u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_HANDLE_HAVE_NAME: PSS_HANDLE_FLAGS = 2u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_HANDLE_HAVE_BASIC_INFORMATION: PSS_HANDLE_FLAGS = 4u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_HANDLE_HAVE_TYPE_SPECIFIC_INFORMATION: PSS_HANDLE_FLAGS = 8u32;
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_HANDLE_INFORMATION {
     pub HandlesCaptured: u32,
 }
@@ -278,6 +297,7 @@ impl ::core::clone::Clone for PSS_HANDLE_INFORMATION {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_TRACE_INFORMATION {
     pub SectionHandle: super::super::super::Foundation::HANDLE,
@@ -291,22 +311,24 @@ impl ::core::clone::Clone for PSS_HANDLE_TRACE_INFORMATION {
         *self
     }
 }
-#[repr(transparent)]
-pub struct PSS_OBJECT_TYPE(pub i32);
-pub const PSS_OBJECT_TYPE_UNKNOWN: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(0i32);
-pub const PSS_OBJECT_TYPE_PROCESS: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(1i32);
-pub const PSS_OBJECT_TYPE_THREAD: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(2i32);
-pub const PSS_OBJECT_TYPE_MUTANT: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(3i32);
-pub const PSS_OBJECT_TYPE_EVENT: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(4i32);
-pub const PSS_OBJECT_TYPE_SECTION: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(5i32);
-pub const PSS_OBJECT_TYPE_SEMAPHORE: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(6i32);
-impl ::core::marker::Copy for PSS_OBJECT_TYPE {}
-impl ::core::clone::Clone for PSS_OBJECT_TYPE {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub type PSS_OBJECT_TYPE = i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_OBJECT_TYPE_UNKNOWN: PSS_OBJECT_TYPE = 0i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_OBJECT_TYPE_PROCESS: PSS_OBJECT_TYPE = 1i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_OBJECT_TYPE_THREAD: PSS_OBJECT_TYPE = 2i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_OBJECT_TYPE_MUTANT: PSS_OBJECT_TYPE = 3i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_OBJECT_TYPE_EVENT: PSS_OBJECT_TYPE = 4i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_OBJECT_TYPE_SECTION: PSS_OBJECT_TYPE = 5i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_OBJECT_TYPE_SEMAPHORE: PSS_OBJECT_TYPE = 6i32;
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_PERFORMANCE_COUNTERS {
     pub TotalCycleCount: u64,
     pub TotalWallClockPeriod: u64,
@@ -327,22 +349,24 @@ impl ::core::clone::Clone for PSS_PERFORMANCE_COUNTERS {
         *self
     }
 }
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_PERF_RESOLUTION: u32 = 1000000u32;
-#[repr(transparent)]
-pub struct PSS_PROCESS_FLAGS(pub u32);
-pub const PSS_PROCESS_FLAGS_NONE: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(0u32);
-pub const PSS_PROCESS_FLAGS_PROTECTED: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(1u32);
-pub const PSS_PROCESS_FLAGS_WOW64: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(2u32);
-pub const PSS_PROCESS_FLAGS_RESERVED_03: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(4u32);
-pub const PSS_PROCESS_FLAGS_RESERVED_04: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(8u32);
-pub const PSS_PROCESS_FLAGS_FROZEN: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(16u32);
-impl ::core::marker::Copy for PSS_PROCESS_FLAGS {}
-impl ::core::clone::Clone for PSS_PROCESS_FLAGS {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub type PSS_PROCESS_FLAGS = u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_PROCESS_FLAGS_NONE: PSS_PROCESS_FLAGS = 0u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_PROCESS_FLAGS_PROTECTED: PSS_PROCESS_FLAGS = 1u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_PROCESS_FLAGS_WOW64: PSS_PROCESS_FLAGS = 2u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_PROCESS_FLAGS_RESERVED_03: PSS_PROCESS_FLAGS = 4u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_PROCESS_FLAGS_RESERVED_04: PSS_PROCESS_FLAGS = 8u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_PROCESS_FLAGS_FROZEN: PSS_PROCESS_FLAGS = 16u32;
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_PROCESS_INFORMATION {
     pub ExitStatus: u32,
@@ -380,23 +404,26 @@ impl ::core::clone::Clone for PSS_PROCESS_INFORMATION {
         *self
     }
 }
-#[repr(transparent)]
-pub struct PSS_QUERY_INFORMATION_CLASS(pub i32);
-pub const PSS_QUERY_PROCESS_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(0i32);
-pub const PSS_QUERY_VA_CLONE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(1i32);
-pub const PSS_QUERY_AUXILIARY_PAGES_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(2i32);
-pub const PSS_QUERY_VA_SPACE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(3i32);
-pub const PSS_QUERY_HANDLE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(4i32);
-pub const PSS_QUERY_THREAD_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(5i32);
-pub const PSS_QUERY_HANDLE_TRACE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(6i32);
-pub const PSS_QUERY_PERFORMANCE_COUNTERS: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(7i32);
-impl ::core::marker::Copy for PSS_QUERY_INFORMATION_CLASS {}
-impl ::core::clone::Clone for PSS_QUERY_INFORMATION_CLASS {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub type PSS_QUERY_INFORMATION_CLASS = i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_QUERY_PROCESS_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 0i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_QUERY_VA_CLONE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 1i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_QUERY_AUXILIARY_PAGES_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 2i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_QUERY_VA_SPACE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 3i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_QUERY_HANDLE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 4i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_QUERY_THREAD_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 5i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_QUERY_HANDLE_TRACE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 6i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_QUERY_PERFORMANCE_COUNTERS: PSS_QUERY_INFORMATION_CLASS = 7i32;
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Kernel'*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Kernel"))]
 pub struct PSS_THREAD_ENTRY {
     pub ExitStatus: u32,
@@ -427,17 +454,14 @@ impl ::core::clone::Clone for PSS_THREAD_ENTRY {
         *self
     }
 }
-#[repr(transparent)]
-pub struct PSS_THREAD_FLAGS(pub u32);
-pub const PSS_THREAD_FLAGS_NONE: PSS_THREAD_FLAGS = PSS_THREAD_FLAGS(0u32);
-pub const PSS_THREAD_FLAGS_TERMINATED: PSS_THREAD_FLAGS = PSS_THREAD_FLAGS(1u32);
-impl ::core::marker::Copy for PSS_THREAD_FLAGS {}
-impl ::core::clone::Clone for PSS_THREAD_FLAGS {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub type PSS_THREAD_FLAGS = u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_THREAD_FLAGS_NONE: PSS_THREAD_FLAGS = 0u32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_THREAD_FLAGS_TERMINATED: PSS_THREAD_FLAGS = 1u32;
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_THREAD_INFORMATION {
     pub ThreadsCaptured: u32,
     pub ContextLength: u32,
@@ -449,6 +473,7 @@ impl ::core::clone::Clone for PSS_THREAD_INFORMATION {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_VA_CLONE_INFORMATION {
     pub VaCloneHandle: super::super::super::Foundation::HANDLE,
@@ -462,7 +487,7 @@ impl ::core::clone::Clone for PSS_VA_CLONE_INFORMATION {
     }
 }
 #[repr(C)]
-#[cfg(feature = "Win32_Foundation")]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_VA_SPACE_ENTRY {
     pub BaseAddress: *mut ::core::ffi::c_void,
     pub AllocationBase: *mut ::core::ffi::c_void,
@@ -476,17 +501,16 @@ pub struct PSS_VA_SPACE_ENTRY {
     pub ImageBase: *mut ::core::ffi::c_void,
     pub CheckSum: u32,
     pub MappedFileNameLength: u16,
-    pub MappedFileName: super::super::super::Foundation::PWSTR,
+    pub MappedFileName: ::windows_sys::core::PCWSTR,
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for PSS_VA_SPACE_ENTRY {}
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::clone::Clone for PSS_VA_SPACE_ENTRY {
     fn clone(&self) -> Self {
         *self
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_VA_SPACE_INFORMATION {
     pub RegionCount: u32,
 }
@@ -496,15 +520,13 @@ impl ::core::clone::Clone for PSS_VA_SPACE_INFORMATION {
         *self
     }
 }
-#[repr(transparent)]
-pub struct PSS_WALK_INFORMATION_CLASS(pub i32);
-pub const PSS_WALK_AUXILIARY_PAGES: PSS_WALK_INFORMATION_CLASS = PSS_WALK_INFORMATION_CLASS(0i32);
-pub const PSS_WALK_VA_SPACE: PSS_WALK_INFORMATION_CLASS = PSS_WALK_INFORMATION_CLASS(1i32);
-pub const PSS_WALK_HANDLES: PSS_WALK_INFORMATION_CLASS = PSS_WALK_INFORMATION_CLASS(2i32);
-pub const PSS_WALK_THREADS: PSS_WALK_INFORMATION_CLASS = PSS_WALK_INFORMATION_CLASS(3i32);
-impl ::core::marker::Copy for PSS_WALK_INFORMATION_CLASS {}
-impl ::core::clone::Clone for PSS_WALK_INFORMATION_CLASS {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub type PSS_WALK_INFORMATION_CLASS = i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_WALK_AUXILIARY_PAGES: PSS_WALK_INFORMATION_CLASS = 0i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_WALK_VA_SPACE: PSS_WALK_INFORMATION_CLASS = 1i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_WALK_HANDLES: PSS_WALK_INFORMATION_CLASS = 2i32;
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
+pub const PSS_WALK_THREADS: PSS_WALK_INFORMATION_CLASS = 3i32;
